@@ -25,11 +25,14 @@ import firefly_aws.domain as domain
 @ff.authenticator()
 class CognitoAuthenticator(ff.Handler, ff.LoggerAware):
     _jwt_decoder: domain.JwtDecoder = None
+    _kernel: ffd.Kernel = None
 
     def handle(self, message: ffd.Message) -> Optional[bool]:
-        if 'http_request' in message.headers and message.headers.get('secured', True):
+        self.debug('Authenticating with Cognito')
+        self.debug(self._kernel)
+        if self._kernel.http_request and self._kernel.secured:
             token = None
-            for k, v in message.headers['http_request']['headers'].items():
+            for k, v in self._kernel.http_request['headers'].items():
                 if k.lower() == 'authorization':
                     if not v.lower().startswith('bearer'):
                         raise ff.UnauthenticatedError()
@@ -52,18 +55,22 @@ class CognitoAuthenticator(ff.Handler, ff.LoggerAware):
                     self.debug('%s in %s', client_claim, groups)
                     if client_claim in groups:
                         scopes.append(client_claim)
+                    elif client_claim.startswith('tenant.'):
+                        tenant_id = client_claim.split(':')[1]
+                        self.debug('Setting tenant to %s', tenant_id)
+                        self._kernel.user.tenant = tenant_id
             elif claims['client_id'] == claims['sub']:
                 scopes = list(map(lambda c: c.replace('/', '.').lower(), claims['scope'].split(' ')))
                 for scope in scopes:
                     if scope.startswith('tenant.'):
-                        message.headers['tenant'] = scope.split(':')[1]
+                        tenant_id = scope.split(':')[1]
+                        self.debug('Setting tenant to %s', tenant_id)
+                        self._kernel.user.tenant = tenant_id
                         break
 
+            self._kernel.user.scopes = scopes
             claims['scopes'] = scopes
-            self.debug('Scopes: %s', claims['scopes'])
-
-            self.debug('Got sub: %s', claims['sub'])
-            message.headers['decoded_token'] = claims
+            self._kernel.user.token = claims
             return True
 
-        return message.headers.get('secured') is not True
+        return self._kernel.secured is not True
